/* eslint-disable no-undef */
import PhraseApi from "../phrase_api";

const returnedVersion = "123";
const baseUrl = "http://localhost:8080";
const dist = "dist";
const env = "env";
const locale = "locale";
const format = "format";
const uuid = "uuid";
const sdkVersion = "sdkVersion";
const lastUpdate = "lastUpdate";
const currentVersion = "currentVersion";
const appVersion = "appVersion";

const api = new PhraseApi(baseUrl);

beforeEach(() => {
  fetch.mockResponseOnce((req) =>
    Promise.resolve({
      url: `http://localhost:8080/file?version=${returnedVersion}`,
      body: JSON.stringify({ requestUrl: req.url })
    })
  );
});

test("getTranslations", async () => {
  const phraseResponse = await api.getTranslations(
    dist,
    env,
    locale,
    format,
    uuid,
    sdkVersion,
    lastUpdate,
    currentVersion,
    appVersion
  );
  expect(phraseResponse.version).toEqual(returnedVersion);
  expect(phraseResponse.json.requestUrl).toEqual(
    `http://localhost:8080/dist/env/locale/format?client=react_native&sdk_version=sdkVersion&unique_identifier=${uuid}&last_update=lastUpdate&current_version=currentVersion&app_version=appVersion`
  );
});

test("getTranslations when baseUrl has trailing slash", async () => {
  const apiWithTrailingSlash = new PhraseApi("http://localhost:8080/");
  const phraseResponse = await apiWithTrailingSlash.getTranslations(
    dist,
    env,
    locale,
    format,
    uuid,
    sdkVersion,
    lastUpdate,
    currentVersion,
    appVersion
  );
  expect(phraseResponse.version).toEqual(returnedVersion);
  expect(phraseResponse.json.requestUrl).toEqual(
    `http://localhost:8080/dist/env/locale/format?client=react_native&sdk_version=sdkVersion&unique_identifier=${uuid}&last_update=lastUpdate&current_version=currentVersion&app_version=appVersion`
  );
});
