export class PhraseResponse {
  constructor (version, json) {
    this.version = version;
    this.json = json;
  }
}

class PhraseApiError extends Error {}

export default class PhraseApi {
  constructor (baseUrl) {
    this.baseUrl = baseUrl;
  }

  async getTranslations (
    distribution,
    environment,
    locale,
    fileFormat,
    uuid,
    sdkVersion,
    lastUpdate,
    currentVersion,
    appVersion
  ) {
    const params = {
      client: "react_native",
      sdk_version: sdkVersion,
      unique_identifier: uuid
    };
    if (lastUpdate != null) params.last_update = lastUpdate;
    if (currentVersion != null) params.current_version = currentVersion;
    if (appVersion != null) params.app_version = appVersion;

    const url = new URL(
      `${distribution}/${environment}/${locale}/${fileFormat}`, this.baseUrl
    );
    Object.keys(params).forEach((key) => {
      url.searchParams.set(key, params[key]);
    });

    const response = await fetch(url.toString(), {
      method: "GET",
      headers: {
        Accept: "application/json",
        "Content-Type": "application/json"
      }
    });
    const code = response.status;
    if (code >= 200 && code <= 299) {
      const url = new URL(response.url);
      const version = url.searchParams.get("version");
      const json = await response.json();
      return new PhraseResponse(version, json);
    } else if (code === 304) {
      return null;
    } else {
      throw new PhraseApiError("HTTP code " + code);
    }
  }
}
