import AsyncStorage from "@react-native-async-storage/async-storage";

import Phrase from "./phrase";

export default class PhraseRepository {
  #PREFIX_PREF = "phrase_pref_";
  #PREFIX_CACHE = "phrase_cache_";

  #KEY_UUID = "uuid";
  #KEY_LAST_UPDATE = "last_update";
  #KEY_TRANSLATION_VER = "version_";

  async getPref (key) {
    try {
      return await AsyncStorage.getItem("@" + this.#PREFIX_PREF + key);
    } catch (e) {
      Phrase.log(`Error reading pref for '${key}': ${e}`);
      return null;
    }
  }

  async setPref (key, value) {
    try {
      await AsyncStorage.setItem("@" + this.#PREFIX_PREF + key, value);
    } catch (e) {
      Phrase.log(`Error storing pref for '${key}': ${e}`);
    }
  }

  async getUuid () {
    let uuid = await this.getPref(this.#KEY_UUID);
    if (uuid != null) return uuid;
    uuid = "00-0-4-1-000".replace(/[^-]/g, (s) =>
      (((Math.random() + ~~s) * 0x10000) >> s).toString(16).padStart(4, "0")
    );
    // console.log("UUID: " + uuid);
    await this.setPref(this.#KEY_UUID, uuid);
    return uuid;
  }

  async getLastUpdate () {
    return await this.getPref(this.#KEY_LAST_UPDATE);
  }

  async setLastUpdate () {
    const seconds = Math.floor(new Date().getTime() / 1000).toString();
    await this.setPref(this.#KEY_LAST_UPDATE, seconds);
  }

  async setVersion (localeHash, version) {
    await this.setPref(this.#KEY_TRANSLATION_VER + localeHash, version);
  }

  async getVersion (localeHash) {
    return await this.getPref(this.#KEY_TRANSLATION_VER + localeHash);
  }

  async getCache (lang) {
    try {
      return JSON.parse(
        await AsyncStorage.getItem("@" + this.#PREFIX_CACHE + lang)
      );
    } catch (e) {
      return null;
    }
  }

  async setCache (lang, value) {
    try {
      await AsyncStorage.setItem(
        "@" + this.#PREFIX_CACHE + lang,
        JSON.stringify(value)
      );
    } catch (e) {
      Phrase.log(`Error storing cache: ${e}`);
    }
  }
}
